@@ -8,12 +8,15 @@ from ...prototype import WikiTextHtml
 
 def replace(instance: WikiTextHtml, wikilink: wikitextparser.WikiLink):
     url = wikilink.title.strip()
-    try:
-        title = instance.clean_title(url)
-    except InvalidWikiLink as e:
-        # Errors always end with a dot, hence the [:-1].
-        instance.add_error(f'{e.args[0][:-1]} (wikilink "{wikilink.string}").')
-        return
+    if url:
+        try:
+            title = instance.clean_title(url)
+        except InvalidWikiLink as e:
+            # Errors always end with a dot, hence the [:-1].
+            instance.add_error(f'{e.args[0][:-1]} (wikilink "{wikilink.string}").')
+            return
+    else:
+        title = ""
 
     if wikilink.text is None:
         text = title
@@ -32,7 +35,7 @@ def replace(instance: WikiTextHtml, wikilink: wikitextparser.WikiLink):
     link_extra = ""
 
     if url and not instance.page_exists(url):
-        instance.add_error(f'Linked page "{wikilink.title}"" does not exist (wikilink "{wikilink.string}").')
+        instance.add_error(f'Linked page "{wikilink.title}" does not exist (wikilink "{wikilink.string}").')
         link_extra = ' class="new"'
 
     hash = ""
